import React, { ReactElement } from "react"
import { Content, Link, Card, Events } from "@onegeo-suite/gatsby-theme-onegeo"

function card(): ReactElement {
    return (
        <Content>
            <div className="prose">
                <Link to="/doc/core">Retour</Link>

                <h1>Card</h1>
                <h2>Props</h2>
                <div className="mockup-code">
                    <pre>
                        <code>
                            {`interface IStyle {
    main: string
    description: string
    image: string
}

interface CardProps {
    children?: React.ReactNode
    name?: string
    description?: string
    image?: string
    url?: string
    anime?: boolean
    layout?: "top" | "left" | "full"
    className?: string
    size?: "xs" | "base" | "xl"
    style?: IStyle
}`}
                        </code>
                    </pre>
                </div>

                <h2>Example</h2>
            </div>
            <div className="m-4 flex flex-col gap-4">
                <h2>Left</h2>
                <Card
                    url="#"
                    name="A very long title : Le lorem ipsum est, en imprimerie, une suite de mots sans signification"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la "
                    layout="left"
                    size="base"
                    image="mock-square"
                />
                <Card
                    url="#"
                    name="A title"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    layout="left"
                    size="base"
                    image="mock-landscape"
                />
                <Card
                    url="#"
                    name="A title "
                    description="Le lorem ipsum"
                    layout="left"
                    size="base"
                    image="mock-portrait"
                />
            </div>
            <div className="m-4 flex flex-col gap-4">
                <h2>Left : xs, base, xl</h2>
                <Card
                    url="#"
                    name="A very long title : Le lorem ipsum est, en imprimerie, une suite de mots sans signification"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la "
                    layout="left"
                    size="xs"
                    image="mock"
                />
                <Card
                    url="#"
                    name="A title"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    layout="left"
                    size="base"
                    image="mock"
                />
                <Card
                    url="#"
                    name="A title "
                    description="Le lorem ipsum"
                    layout="left"
                    size="xl"
                    image="mock"
                />
            </div>
            <h2>Top : base</h2>
            <div className="m-4 flex justify-center gap-6">
                <Card
                    url="#"
                    name="Title"
                    size="base"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock-square"
                />
                <Card
                    url="#"
                    name="Title"
                    size="base"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie"
                    image="mock-landscape"
                />
                <Card
                    url="#"
                    name="Title title title"
                    size="base"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock-portrait"
                />
            </div>
            <h2>Top : XL</h2>
            <div className="m-4 flex justify-center gap-6">
                <Card
                    url="#"
                    name="Title"
                    size="xl"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock"
                />
                <Card
                    url="#"
                    name="Title"
                    size="xl"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock"
                />
                <Card
                    url="#"
                    name="Title"
                    size="xl"
                    layout="top"
                    description="titre provisoire pour calibrer une mise en page"
                    image="mock"
                />
            </div>
            <h2>Top : xs</h2>
            <div className="m-4 flex justify-center gap-6">
                <Card
                    url="#"
                    name="Title"
                    size="xs"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock"
                />
                <Card
                    url="#"
                    name="Title"
                    size="xs"
                    layout="top"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock"
                />
                <Card
                    url="#"
                    name="Title"
                    size="xs"
                    layout="top"
                    description="Le lorem ipsum es "
                    image="mock"
                />
            </div>
            <h2>Full</h2>
            <div className="m-4 flex justify-center gap-6">
                <Card
                    url="#"
                    name="Title"
                    description="Description for the card, Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la,Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que laLe lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    image="mock"
                    layout="full"
                />
                <Card
                    url="#"
                    name="Title"
                    description="Description for the card"
                    image="mock"
                    layout="full"
                />
                <Card
                    url="#"
                    name="Title"
                    description="Description for the card,"
                    image="mock"
                    layout="full"
                />
            </div>
            <div className="m-4 flex gap-6">
                <Card
                    url="#"
                    name="Title"
                    description="Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la Le lorem ipsum est, en imprimerie, une suite de mots sans signification utilisée à titre provisoire pour calibrer une mise en page, le texte définitif venant remplacer le faux-texte dès qu'il est prêt ou que la"
                    layout="left"
                    image="mock"
                />
            </div>
            <div className="m-4 flex gap-6">
                <Card
                    name="A very long title : Le lorem ipsum est, en imprimerie, une suite de mots sans signification"
                    description="Action whith icon on top for the Button"
                    layout="left"
                    image="mock"
                    anime={false}
                    className="shadow-none"
                />
            </div>
            <div className="m-4 flex gap-6">
                <Card
                    options={{
                        class: {
                            main: "card-side h-52 w-full h-auto",
                            image: "min-w-[320px] max-w-[320px]",
                        },
                    }}
                    anime={false}
                >
                    <Events />
                </Card>
            </div>
        </Content>
    )
}

export default card
